@@ -22,6 +22,7 @@
 #include "notificationsourceinterface.h"
 #include "notificationmanagerinterface.h"
 #include "changemediator_p.h"
+#include "servermanager.h"
 
 #include <KComponentData>
 #include <KGlobal>
@@ -31,21 +32,30 @@ using namespace Akonadi;
 
 QObject* ChangeNotificationDependenciesFactory::createNotificationSource(QObject *parent)
 {
-  org::freedesktop::Akonadi::NotificationManager manager(
-          QLatin1String( "org.freedesktop.Akonadi" ),
-          QLatin1String( "/notifications" ),
-          DBusConnectionPool::threadConnection() );
+  org::freedesktop::Akonadi::NotificationManager *manager =
+    new org::freedesktop::Akonadi::NotificationManager(
+      ServerManager::serviceName( Akonadi::ServerManager::Server ),
+      QLatin1String( "/notifications" ),
+      DBusConnectionPool::threadConnection() );
 
-  QDBusObjectPath p = manager.subscribe( KGlobal::mainComponent().componentName() );
-  if ( manager.lastError().isValid() ) {
+  if ( !manager ) {
+    // :TODO: error handling
+    return 0;
+  }
+
+  QDBusObjectPath p = manager->subscribe( KGlobal::mainComponent().componentName() );
+  const bool validError = manager->lastError().isValid();
+  delete manager;
+  if ( validError ) {
     // :TODO: What to do?
     return 0;
   }
 
-  org::freedesktop::Akonadi::NotificationSource *notificationSource = new org::freedesktop::Akonadi::NotificationSource(
-              QLatin1String( "org.freedesktop.Akonadi" ),
-              p.path(),
-              DBusConnectionPool::threadConnection(), parent );
+  org::freedesktop::Akonadi::NotificationSource *notificationSource =
+    new org::freedesktop::Akonadi::NotificationSource(
+      ServerManager::serviceName( Akonadi::ServerManager::Server ),
+      p.path(),
+      DBusConnectionPool::threadConnection(), parent );
 
   if ( !notificationSource ) {
     // :TODO: error handling
@@ -62,10 +72,10 @@ QObject* ChangeNotificationDependenciesFactory::createChangeMediator(QObject* pa
 
 CollectionCache* ChangeNotificationDependenciesFactory::createCollectionCache(int maxCapacity, Session *session)
 {
-  return new CollectionCache(maxCapacity, session);
+  return new CollectionCache( maxCapacity, session );
 }
 
 ItemCache* ChangeNotificationDependenciesFactory::createItemCache(int maxCapacity, Session* session)
 {
-  return new ItemCache(maxCapacity, session);
+  return new ItemCache( maxCapacity, session );
 }
