@@ -56,7 +56,7 @@
 #include <QtCore/QHash>
 #include <QtCore/QSettings>
 #include <QtCore/QTimer>
-#include <QtGui/QApplication>
+#include <QApplication>
 #include <QtDBus/QtDBus>
 
 using namespace Akonadi;
@@ -93,7 +93,7 @@ class Akonadi::ResourceBasePrivate : public AgentBasePrivate
 
     void delayedInit()
     {
-      const QString serviceId = QLatin1String(  "org.freedesktop.Akonadi.Resource." ) + mId;
+      const QString serviceId = ServerManager::agentServiceName( ServerManager::Resource, mId );
       if ( !DBusConnectionPool::threadConnection().registerService( serviceId ) ) {
         QString reason = DBusConnectionPool::threadConnection().lastError().message();
         if ( reason.isEmpty() ) {
@@ -432,7 +432,7 @@ QString ResourceBase::parseArguments( int argc, char **argv )
   // strip off full path and possible .exe suffix
   const QByteArray catalog = fi.baseName().toLatin1();
 
-  KCmdLineArgs::init( argc, argv, identifier.toLatin1(), catalog,
+  KCmdLineArgs::init( argc, argv, ServerManager::addNamespace( identifier ).toLatin1(), catalog,
                       ki18nc( "@title application name", "Akonadi Resource" ), KDEPIMLIBS_VERSION,
                       ki18nc( "@title application description", "Akonadi Resource" ) );
 
