@@ -1,24 +1,24 @@
 /*
-    Copyright (c) 2009 Constantin Berzan <exit3219@gmail.com>
+  Copyright (c) 2009 Constantin Berzan <exit3219@gmail.com>
 
-    Based on KMail code by:
-    Copyright (c) 2002 Marc Mutz <mutz@kde.org>
-                  2007 Mathias Soeken <msoeken@tzi.de>
+  Based on KMail code by:
+  Copyright (c) 2002 Marc Mutz <mutz@kde.org>
+  Copyright (c) 2007 Mathias Soeken <msoeken@tzi.de>
 
-    This library is free software; you can redistribute it and/or modify it
-    under the terms of the GNU Library General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or (at your
-    option) any later version.
+  This library is free software; you can redistribute it and/or modify it
+  under the terms of the GNU Library General Public License as published by
+  the Free Software Foundation; either version 2 of the License, or (at your
+  option) any later version.
 
-    This library is distributed in the hope that it will be useful, but WITHOUT
-    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
-    License for more details.
+  This library is distributed in the hope that it will be useful, but WITHOUT
+  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
+  License for more details.
 
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to the
-    Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-    02110-1301, USA.
+  You should have received a copy of the GNU Library General Public License
+  along with this library; see the file COPYING.LIB.  If not, write to the
+  Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
+  02110-1301, USA.
 */
 
 #include "transportlistview.h"
@@ -42,7 +42,7 @@ TransportListView::TransportListView( QWidget *parent )
                      << i18nc( "@title:column email transport type", "Type" ) );
   setRootIsDecorated( false );
   header()->setMovable( false );
-  header()->setResizeMode(QHeaderView::ResizeToContents);
+  header()->setResizeMode( QHeaderView::ResizeToContents );
   setAllColumnsShowFocus( true );
   setAlternatingRowColors( true );
   setSortingEnabled( true );
@@ -100,12 +100,15 @@ void TransportListView::fillTransportList()
   foreach ( Transport *t, TransportManager::self()->transports() ) {
     QTreeWidgetItem *item = new QTreeWidgetItem( this );
     item->setData( 0, Qt::UserRole, t->id() );
-    item->setText( 0, t->name() );
-    QString type = t->transportType().name();
+    QString name = t->name();
     if ( TransportManager::self()->defaultTransportId() == t->id() ) {
-      type += i18nc( "@label the default mail transport", " (Default)" );
+      name += i18nc( "@label the default mail transport", " (Default)" );
+      QFont font(item->font(0));
+      font.setBold(true);
+      item->setFont(0, font);
     }
-    item->setText( 1, type );
+    item->setText( 0, name );
+    item->setText( 1, t->transportType().name() );
     if ( t->id() == selected ) {
       setCurrentItem( item );
     }
